@@ -27,6 +27,11 @@ class BaseConnect(APIRouter):
         raise Exception("not implements")
 
 
+class SqlalchemyConnect(BaseConnect):
+    def __init__(self, *args, **kwargs):
+        super(SqlalchemyConnect, self).__init__(*args, **kwargs)
+
+
 class RedisConnect(BaseConnect):
     def __init__(self, host='localhost', port=6379, *args, **kwargs):
         self.redis_client = redis.Redis(host=host, port=port, decode_responses=False)
